<?php

namespace Drupal\entity_repeat;

use Drupal\Core\Entity\BundlePermissionHandlerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Provides dynamic permissions for nodes of different types.
 */
class EntityRepeatPermissions {
  use BundlePermissionHandlerTrait;
  use StringTranslationTrait;

  /**
   * Returns an array of permissions.
   *
   * @return array
   *   The permissions.
   *
   * @see \Drupal\user\PermissionHandlerInterface::getPermissions()
   */
  public function permissions() {
    // Get entity bundles with Recurring enabled on a date field.
    $bundles = _entity_repeat_get_bundles();

    return $this->generatePermissions($bundles, [$this, 'buildPermissions']);
  }

  /**
   * Returns a list of entity permissions for a given entity type.
   *
   * @param $entity_type
   *   The entity type that the permissions apply to.
   *
   * @return array[]
   *   An array of permission permissions.
   */
  protected function buildPermissions($entity_type) {
    $entity_type_id = $entity_type->id();
    $params = ['%type_name' => $entity_type->label()];

    return [
      "repeat own $entity_type_id content" => [
        'title' => $this->t('%type_name: Repeat own content', $params),
      ],
      "repeat any $entity_type_id content" => [
        'title' => $this->t('%type_name: Repeat any content', $params),
      ],
    ];
  }

}
